@@ -187,7 +187,7 @@ if [ "$IMAGETYPE" != "windows" ]; then
   [ "$VOLUME_SIZE" ] || VOLUME_SIZE=8
 else
   WIN_PASSWD="$(tr -cd '[:alnum:]' < /dev/urandom | head -c16)"
-  PASSWD_ARG="{\"ansible_ssh_pass\": \"$WIN_PASSWD\","
+  PASSWD_ARG="{\"ansible_password\": \"$WIN_PASSWD\","
   PASSWD_ARG="$PASSWD_ARG \"ansible_winrm_operation_timeout_sec\": 60,"
   PASSWD_ARG="$PASSWD_ARG \"ansible_winrm_read_timeout_sec\": 70,"
   PASSWD_ARG="$PASSWD_ARG \"ansible_winrm_server_cert_validation\": \"ignore\","
@@ -313,7 +313,7 @@ if $(which ansible-playbook) \
   -e root_ami=$AMI \
   -e tstamp=$TSTAMP \
   -e aws_region=$REGION \
-  -e ansible_ssh_user=$SSH_USER \
+  -e ansible_user=$SSH_USER \
   -e imagedir="$(realpath "${imagedir}")" \
   -e subnet_id=$SUBNET \
   -e sg_id=$SECURITY_GROUP \
