@@ -4,7 +4,7 @@ import re
 import json
 from datetime import datetime
 from os import R_OK, access
-from os.path import exists, expanduser, isfile, join
+from os.path import exists, expanduser, isfile, join, isdir
 
 import argcomplete
 from argcomplete.completers import ChoicesCompleter
@@ -64,9 +64,15 @@ def read_profiles(prefix=""):
                     ret.append(profile[8:])
     return ret
 
+PROFILES= {}
+PROFILES_WITH_CREDS = {}
 
 def get_profile(profile, include_creds=True):
     home = expanduser("~")
+    if include_creds and profile in PROFILES_WITH_CREDS:
+        return PROFILES_WITH_CREDS[profile]
+    elif not include_creds and profile in PROFILES:
+        return PROFILES[profile]
     from collections import OrderedDict
 
     ret = OrderedDict()
@@ -88,43 +94,48 @@ def get_profile(profile, include_creds=True):
                 if profile in parser.sections():
                     for option in parser.options(profile):
                         ret[option] = parser.get(profile, option)
+        PROFILES_WITH_CREDS[profile] = ret
+    PROFILES[profile] = ret
     return ret
 
 
-def read_profile_expiry(profile):
-    home = expanduser("~")
-    credentials = join(home, ".aws", "credentials")
-    if exists(credentials):
-        parser = ConfigParser()
-        with open(credentials) as credfile:
-            parser.read_file(credfile)
-            if parser.has_option(profile, "aws_expiration"):
-                return parser.get(profile, "aws_expiration")
-            elif parser.has_option(profile, "aws_session_expiration"):
-                return parser.get(profile, "aws_session_expiration")
-    return "1970-01-01T00:00:00.000Z"
+def read_profile_expiry(profile, profile_type=None):
+    if profile_type != "sso":
+        home = expanduser("~")
+        credentials = join(home, ".aws", "credentials")
+        if exists(credentials):
+            parser = ConfigParser()
+            with open(credentials) as credfile:
+                parser.read_file(credfile)
+                if parser.has_option(profile, "aws_expiration"):
+                    return parser.get(profile, "aws_expiration")
+                elif parser.has_option(profile, "aws_session_expiration"):
+                    return parser.get(profile, "aws_session_expiration")
+    return read_sso_profile_expiry(profile)
 
 def read_sso_profile_expiry(profile):
+    profile_data = read_sso_profile(profile)
+    if profile_data:
+        return profile_data.get("expiresAt", "1970-01-01T00:00:00Z")[:-1] + ".000Z"
+    return "1970-01-01T00:00:00.000Z"
+
+def read_sso_profile(profile):
     profile_data = get_profile(profile, include_creds=False)
     if "sso_start_url" in profile_data:
         home = expanduser("~")
         sso_cache = join(home, ".aws", "sso", "cache")
-        for filename in os.listdir(sso_cache):
-            full_file = os.path.join(sso_cache, filename)
-            if isfile(full_file) and access(full_file, R_OK):
-                with open(full_file, "r") as cache_file:
-                    cache_json = json.load(cache_file)
-                    if cache_json and "startUrl" in cache_json and cache_json["startUrl"] == profile_data["sso_start_url"] and "expiresAt" in cache_json and cache_json["expiresAt"]:
-                        return cache_json["expiresAt"]
-    return "1970-01-01T00:00:00.000Z"
-
-
-def read_profile_expiry_epoc(profile):
-    return _epoc_secs(parse(read_profile_expiry(profile)).replace(tzinfo=tzutc()))
-
-def read_sso_profile_expiry_epoc(profile):
-    return _epoc_secs(parse(read_sso_profile_expiry(profile)).replace(tzinfo=tzutc()))
+        if isdir(sso_cache):
+            for filename in os.listdir(sso_cache):
+                full_file = os.path.join(sso_cache, filename)
+                if isfile(full_file) and access(full_file, R_OK):
+                    with open(full_file, "r") as cache_file:
+                        cache_json = json.load(cache_file)
+                        if cache_json and "startUrl" in cache_json and cache_json["startUrl"] == profile_data["sso_start_url"]:
+                            return cache_json
+    return {}
 
+def read_profile_expiry_epoc(profile, profile_type=None):
+    return _epoc_secs(parse(read_profile_expiry(profile, profile_type=profile_type)).replace(tzinfo=tzutc()))
 
 def print_aws_profiles():
     """Prints profile names from credentials file (~/.aws/credentials) and the conf file (~/.aws/conf) for autocomplete tools"""
@@ -247,10 +258,14 @@ def profile_expiry_to_env():
     print_profile_expiry(args.profile)
 
 
-def print_profile_expiry(profile):
+def print_profile_expiry(profile, expiry_epoc=None):
     safe_profile = re.sub("[^A-Z0-9]", "_", profile.upper())
-    expiry = read_profile_expiry(profile)
-    epoc = _epoc_secs(parse(expiry).replace(tzinfo=tzutc()))
+    if expiry_epoc:
+        epoc = expiry_epoc
+        expiry = _epoc_to_str(epoc)
+    else:
+        expiry = read_profile_expiry(profile)
+        epoc = _epoc_secs(parse(expiry).replace(tzinfo=tzutc()))
     print("AWS_SESSION_EXPIRATION_EPOC_" + safe_profile + "=" + str(epoc))
     print("AWS_SESSION_EXPIRATION_" + safe_profile + "=" + expiry)
     print(
@@ -476,10 +491,10 @@ def enable_profile(profile_type, profile):
         _print_profile_switch(profile)
         if "AWS_SESSION_EXPIRATION_EPOC_" + safe_profile in os.environ:
             expiry = int(os.environ["AWS_SESSION_EXPIRATION_EPOC_" + safe_profile])
-        if expiry < now and profile_type != "sso":
-            expiry = read_profile_expiry_epoc(profile)
-        elif expiry < now:
-            expiry = read_sso_profile_expiry_epoc(profile)
+        if expiry < now:
+            expiry = read_profile_expiry_epoc(profile, profile_type=profile_type)
+            if "AWS_SESSION_EXPIRATION_EPOC_" + safe_profile in os.environ:
+                del os.environ["AWS_SESSION_EXPIRATION_EPOC_" + safe_profile]
         if expiry < now:
             bw_prefix = ""
             bw_entry = None
@@ -536,7 +551,7 @@ def enable_profile(profile_type, profile):
             elif profile_type == "sso":
                 print("aws sso login --profile " + profile)
         elif "AWS_SESSION_EXPIRATION_EPOC_" + safe_profile not in os.environ:
-            print_profile_expiry(profile)
+            print_profile_expiry(profile, expiry_epoc=expiry)
     elif profile_type == "ndt":
         if "AWS_SESSION_EXPIRATION_EPOC_" + safe_profile in os.environ:
             expiry = int(os.environ["AWS_SESSION_EXPIRATION_EPOC_" + safe_profile])
@@ -573,7 +588,7 @@ def enable_profile(profile_type, profile):
             command.append(profile_data["ndt_role_arn"])
             print(" ".join(command))
         elif "AWS_SESSION_EXPIRATION_EPOC_" + safe_profile not in os.environ:
-            print_profile_expiry(profile)
+            print_profile_expiry(profile, expiry_epoc=expiry)
         _print_profile_switch(profile)
     elif profile_type == "azure-subscription":
         if not (
@@ -608,6 +623,9 @@ def _print_profile_switch(profile):
         print("export " + " ".join(set_env) + ";")
 
 
+def _epoc_to_str(epoc):
+    return datetime.utcfromtimestamp(epoc).strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+
 def _epoc_secs(d):
     return int(
         (d - datetime.utcfromtimestamp(0).replace(tzinfo=tzutc())).total_seconds()
